Index: pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart |
diff --git a/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart b/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart |
index a5d7b09fe6e530e0e916e2975d237970694f92e8..4933378f113dd879b84d867a6b28840fed4c72e2 100644 |
--- a/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart |
+++ b/pkg/front_end/lib/src/fasta/scanner/array_based_scanner.dart |
@@ -262,9 +262,9 @@ abstract class ArrayBasedScanner extends AbstractScanner { |
@override |
void appendSyntheticSubstringToken( |
- TokenType type, int start, bool asciiOnly, String closingQuotes) { |
+ TokenType type, int start, bool asciiOnly, String syntheticChars) { |
appendToken( |
- createSyntheticSubstringToken(type, start, asciiOnly, closingQuotes)); |
+ createSyntheticSubstringToken(type, start, asciiOnly, syntheticChars)); |
} |
/** |
@@ -282,13 +282,13 @@ abstract class ArrayBasedScanner extends AbstractScanner { |
/** |
* Returns a new synthetic substring from the scan offset [start] |
* to the current [scanOffset] plus the [closingQuotes]. |
* The [closingQuotes] are appended to the unterminated string |
* literal's lexeme but the returned token's length will *not* include |
- * those closing quotes so as to be true to the original source. |
+ * those additional characters so as to be true to the original source. |
*/ |
analyzer.StringToken createSyntheticSubstringToken( |
- TokenType type, int start, bool asciiOnly, String closingQuotes); |
+ TokenType type, int start, bool asciiOnly, String syntheticChars); |
/** |
* This method is called to discard '<' from the "grouping" stack. |
@@ -282,13 +282,13 @@ abstract class ArrayBasedScanner extends AbstractScanner { |
/** |
* Returns a new synthetic substring from the scan offset [start] |
- * to the current [scanOffset] plus the [closingQuotes]. |
- * The [closingQuotes] are appended to the unterminated string |
+ * to the current [scanOffset] plus the [syntheticChars]. |
+ * The [syntheticChars] are appended to the unterminated string |
* literal's lexeme but the returned token's length will *not* include |